@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-acr.h,v 1.25 2005/05/16 07:35:00 enlf Exp $ 
+/* $Id: m-acr.h,v 1.26 2005/12/16 23:33:04 enlf Exp $ 
  */
 
 /*
@@ -78,8 +78,6 @@ typedef struct MdcDicomStuff_t {
   /* window / rescale */
   float si_slope;
   float si_intercept;
-  float cw_center;
-  float cw_width;
   /* vectors */
   Int8   VectDO[MDC_VECT_TOTAL];
   Uint16 VectNR[MDC_VECT_TOTAL];
