@@ -39,7 +39,7 @@
  *                MdcUnpackBIT12()        - Unpack 12 bit into Uint16      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-algori.c,v 1.70 2005/05/16 07:35:00 enlf Exp $ 
+/* $Id: m-algori.c,v 1.77 2005/12/16 23:34:46 enlf Exp $ 
  */
 
 /*
@@ -65,6 +65,7 @@
 
 #include "m-depend.h"
 #include <stdio.h>
+#define __USE_ISOC99 1
 #include <math.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -250,7 +251,41 @@ void MdcVAXfl_to_IEEEfl(float *f)
 
   memcpy((void *)f,(void *)&number.n4,4);
 
-} 
+}
+
+int MdcFixFloat(float *ref)
+{
+  float value = *ref;
+  int fixed = 0;
+
+#ifdef HAVE_ISNAN
+  if (isnan(value)) { value = 0.; fixed = 1; }
+#endif
+#ifdef HAVE_ISINF
+  if (isinf(value)) { value = 0.; fixed = 1; }
+#endif
+
+  *ref = value;
+
+  return(fixed);
+}
+
+int MdcFixDouble(double *ref)
+{
+  double value = *ref;
+  int fixed = 0;
+
+#ifdef HAVE_ISNAN
+  if (isnan(value)) { value = 0.; fixed = 1; }
+#endif
+#ifdef HAVE_ISINF
+  if (isinf(value)) { value = 0.; fixed = 1; }
+#endif
+
+  *ref = value;
+
+  return(fixed);
+}
 
 int MdcType2Bytes(int type)
 {
@@ -382,6 +417,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
   float start, duration;
   double fmin=0., fmax=0., qfmin=0., qfmax=0.; 
   char *msg;
+  int FixWarn=0;
 
   /* initial checks for FILEINFO integrity */
   if (fi->number == 0) return("Internal Error ## Improper fi->number value");
@@ -563,6 +599,12 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
      n = id->width * id->height;
      sd = id->sdata;
 
+     if (MDC_FORCE_RESCALE) {
+       id->quant_scale = mdc_si_slope;
+       id->calibr_fctr = 1.;
+       id->intercept   = mdc_si_intercept; 
+     }
+
      if (MDC_QUANTIFY) {
        id->rescale_slope = id->quant_scale;
        id->rescale_intercept = id->intercept;
@@ -574,6 +616,15 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
        id->rescale_intercept = 0.;
      }
 
+     if (fi->contrast_remapped == MDC_YES) {
+       /* any rescale already done */
+       id->quant_scale = 1.;
+       id->calibr_fctr = 1.;
+       id->intercept   = 0.;
+       id->rescale_slope = 1.;
+       id->rescale_intercept = 0.;
+     }
+
      switch (id->type) {
 
       case BIT8_U:
@@ -806,6 +857,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
          /* init first pixel */
          memcpy((void *)&pix0,(void *)pix,4);
          MdcSwapBytes((Uint8 *)&pix0, 4);
+         FixWarn |= MdcFixFloat(&pix0);
          if (!MDC_NEGATIVE && (pix0 < 0.)) pix0 = 0.;
 
          /* init max,min values */
@@ -818,6 +870,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
 
          for (i=0; i<n; i++, pix++) {
             MdcSwapBytes((Uint8 *)pix, 4);
+            FixWarn |= MdcFixFloat(pix);
             if (!MDC_NEGATIVE && (*pix < 0.)) *pix = 0.;
             maxmin(*pix, max, min);
             if (sd != NULL) sd->total_counts += (float)*pix;
@@ -835,12 +888,13 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
          /* init first pixel */
          memcpy((void *)&pix0,(void *)pix,8);
          MdcSwapBytes((Uint8 *)&pix0, 8);
+         FixWarn |= MdcFixDouble(&pix0);
          if (!MDC_NEGATIVE && (pix0 < 0.)) pix0 = 0.;
 
          /* init max,min values */
          min = pix0;
          max = pix0;
-         if (j == 0 ) {
+         if (j == 0) {
            fi->glmin = pix0;
            fi->glmax = pix0;
          }
@@ -848,6 +902,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
          /* go through all pixels */
          for (i=0; i<n; i++, pix++) {
             MdcSwapBytes((Uint8 *)pix, 8);
+            FixWarn |= MdcFixDouble(pix);
             if (!MDC_NEGATIVE && (*pix < 0.)) *pix = 0.;
             maxmin(*pix, max, min);
             if (sd != NULL) sd->total_counts += (float)*pix; /* overflow */
@@ -858,6 +913,10 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
        break;
      }
 
+     /* no negatives -> min = 0 */
+     if (!MDC_NEGATIVE && (id->min < 0.)) id->min = 0.;
+
+     /* handle global max,min values */
      if (j == 0) {
        fi->glmin = id->min;  fi->glmax = id->max;
      }else{
@@ -865,22 +924,26 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
        if ( id->min < fi->glmin ) fi->glmin = id->min;
      }
 
-     /* do it even if not MDC_QUANTIFY or not MDC_CALIBRATE */
-     /* handle global min values */
-     if (!MDC_NEGATIVE) { fi->qglmin =  fi->glmin = id->min = 0.; }
-     else { 
-        id->qmin = (double)((float)id->min * id->rescale_slope);
-        id->qmin += (double)id->rescale_intercept;
-        if (j == 0) {
-          fi->qglmin = id->qmin;
-        }else{
-          if ( id->qmin < fi->qglmin) fi->qglmin = id->qmin;
-        }
-     }
-     /* handle global max values */ 
+     /* get quantified max,min */
+     id->qmin = (double)((float)id->min * id->rescale_slope);
+     id->qmin += (double)id->rescale_intercept;
+
      id->qmax = (double)((float)id->max * id->rescale_slope);
      id->qmax += (double)id->rescale_intercept;
 
+     /* negative slope -> reverse qmax,qmin */
+     if (id->rescale_slope < 0.) {
+       double x;
+       x = id->qmin; id->qmin = id->qmax; id->qmax = x;
+     }
+
+     /* handle quantified global min values */
+     if (j == 0) {
+       fi->qglmin = id->qmin;
+     }else{
+       if ( id->qmin < fi->qglmin) fi->qglmin = id->qmin;
+     }
+     /* handle quantified global max values */ 
      if (j == 0) { 
        fi->qglmax = id->qmax;
      }else{
@@ -918,6 +981,9 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
 
   }
 
+  /* warn about fixed values */
+  if (FixWarn) MdcPrntWarn("Fixed image(s) with bad floats (= set to zero)");
+
   /* don't forget to fill in the min/max values for the last frame group */
   for (t=j - fi->dim[3]; t<j ; t++) {        
      idprev = &fi->image[t];
