@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-algori.h,v 1.15 2005/05/16 07:35:00 enlf Exp $
+/* $Id: m-algori.h,v 1.16 2005/12/14 00:05:01 enlf Exp $
  */
 
 /*
@@ -60,6 +60,8 @@ void MdcSwapBytes(Uint8 *ptr, int bytes);
 void MdcForceSwap(Uint8 *ptr, int bytes);
 void MdcIEEEfl_to_VAXfl(float *f);
 void MdcVAXfl_to_IEEEfl(float *f);
+int MdcFixFloat(float *ref);
+int MdcFixDouble(double *ref);
 int MdcType2Bytes(int type);
 int MdcType2Bits(int type);
 double MdcTypeIntMax(int type);
