@@ -17,7 +17,7 @@
  *                MdcGetSpmOpt()           - Get specific SPM options      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-anlz.c,v 1.74 2005/05/16 07:35:00 enlf Exp $
+/* $Id: m-anlz.c,v 1.75 2005/11/17 22:28:32 enlf Exp $
  */
 
 /*
@@ -735,22 +735,37 @@ int MdcWriteDataHistory(FILEINFO *fi, MDC_SPMOPT *opt)
   sprintf(dh.generated,"%.10s",MDC_PRGR);
 
   switch (fi->pat_slice_orient) {
-   case MDC_SUPINE_HEADFIRST_TRANSAXIAL: 
-   case MDC_PRONE_HEADFIRST_TRANSAXIAL :
-   case MDC_SUPINE_FEETFIRST_TRANSAXIAL:
-   case MDC_PRONE_FEETFIRST_TRANSAXIAL : dh.orient = MDC_ANLZ_TRANS_UNFLIPPED;
-                                          break;
-   case MDC_SUPINE_HEADFIRST_CORONAL    :
-   case MDC_PRONE_HEADFIRST_CORONAL     :
-   case MDC_SUPINE_FEETFIRST_CORONAL    :
-   case MDC_PRONE_FEETFIRST_CORONAL     : dh.orient = MDC_ANLZ_CORON_UNFLIPPED;
-                                          break;
+   case MDC_SUPINE_HEADFIRST_TRANSAXIAL         : 
+   case MDC_PRONE_HEADFIRST_TRANSAXIAL          :
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL: 
+   case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
+   case MDC_SUPINE_FEETFIRST_TRANSAXIAL         :
+   case MDC_PRONE_FEETFIRST_TRANSAXIAL          : 
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
+   case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL : 
+     dh.orient = MDC_ANLZ_TRANS_UNFLIPPED;
+     break;
+   case MDC_SUPINE_HEADFIRST_CORONAL             :
+   case MDC_PRONE_HEADFIRST_CORONAL              :
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    :
+   case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     :
+   case MDC_SUPINE_FEETFIRST_CORONAL             :
+   case MDC_PRONE_FEETFIRST_CORONAL              : 
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    :
+   case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     : 
+     dh.orient = MDC_ANLZ_CORON_UNFLIPPED;
+     break;
 
-   case MDC_SUPINE_HEADFIRST_SAGITTAL   :
-   case MDC_PRONE_HEADFIRST_SAGITTAL    :
-   case MDC_SUPINE_FEETFIRST_SAGITTAL   :
-   case MDC_PRONE_FEETFIRST_SAGITTAL    : dh.orient = MDC_ANLZ_SAGIT_UNFLIPPED;
-                                          break;
+   case MDC_SUPINE_HEADFIRST_SAGITTAL            :
+   case MDC_PRONE_HEADFIRST_SAGITTAL             :
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
+   case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
+   case MDC_SUPINE_FEETFIRST_SAGITTAL            :
+   case MDC_PRONE_FEETFIRST_SAGITTAL             : 
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
+   case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    : 
+     dh.orient = MDC_ANLZ_SAGIT_UNFLIPPED;
+     break;
   }
 
   if (opt != NULL) {
