@@ -23,7 +23,7 @@
  * Credits      :                                                          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-conc.c,v 1.82 2005/05/16 07:35:00 enlf Exp $
+/* $Id: m-conc.c,v 1.83 2005/11/17 22:28:32 enlf Exp $
  */
 
 /*
@@ -553,7 +553,7 @@ static void conc_get_int_int(char * line, int * return_code, int * num1, int * n
 }
 
 static void conc_get_int_int_float_float(char * line, int * return_code, int * num1, int * num2,
-					 float * num3, float * num4) {
+                                         float * num3, float * num4) {
 
   *return_code = sscanf(line, "%*s %d %d %f %f", num1, num2, num3, num4);
   if ((*return_code == EOF) || (*return_code <= 0)) *num1 = *num2 = 0;
@@ -840,10 +840,10 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
       switch(acq_type) {
       case MDC_CONC_ACQ_BLANK:
         fi->acquisition_type = MDC_ACQUISITION_STATIC;
-	break;
+        break;
       case MDC_CONC_ACQ_EMISSION:
         fi->acquisition_type = MDC_ACQUISITION_TOMO;
-	break;
+        break;
       case MDC_CONC_ACQ_DYNAMIC:
         fi->acquisition_type = MDC_ACQUISITION_DYNAMIC;
         break;
@@ -852,15 +852,15 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
         break;
       case MDC_CONC_ACQ_CONTINUOUS:
         fi->acquisition_type = MDC_ACQUISITION_TOMO;
-	break;
+        break;
       case MDC_CONC_ACQ_SINGLES:
         fi->acquisition_type = MDC_ACQUISITION_STATIC;
-	transmission_scan = MDC_TRUE;
+        transmission_scan = MDC_TRUE;
         break;
       case MDC_CONC_ACQ_WINDOWED_COINCIDENCE:
       case MDC_CONC_ACQ_NON_WINDOWED_COINCIDENCE:
         fi->acquisition_type = MDC_ACQUISITION_TOMO;
-	transmission_scan = MDC_TRUE;
+        transmission_scan = MDC_TRUE;
         break;
       case MDC_CONC_ACQ_UNKNOWN:
       default:
@@ -1204,16 +1204,16 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
       break;
     case MDC_CONC_HDR_MAP_BLUR_FILE:
       if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
-	temp_string = conc_get_string(line, &return_code);
-	if (MDC_INFO) MdcPrntScrn("MAP Blur File:\t\t\t%s\n",temp_string);
-	MdcFree(temp_string);
+        temp_string = conc_get_string(line, &return_code);
+        if (MDC_INFO) MdcPrntScrn("MAP Blur File:\t\t\t%s\n",temp_string);
+        MdcFree(temp_string);
       }
       break;
     case MDC_CONC_HDR_MAP_PMATRIX_FILE:
       if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
-	temp_string = conc_get_string(line, &return_code);
-	if (MDC_INFO) MdcPrntScrn("MAP PMatrix File:\t\t%s\n",temp_string);
-	MdcFree(temp_string);
+        temp_string = conc_get_string(line, &return_code);
+        if (MDC_INFO) MdcPrntScrn("MAP PMatrix File:\t\t%s\n",temp_string);
+        MdcFree(temp_string);
       }
       break;
     case MDC_CONC_HDR_OSEM2D_METHOD:
@@ -1484,33 +1484,33 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
     case MDC_CONC_HDR_GATE_INPUTS:
       temp_int = conc_get_int(line, &return_code);
       if (MDC_INFO)
-	MdcPrntScrn("Number of Gate Inputs:\t\t%d\n", temp_int);
+        MdcPrntScrn("Number of Gate Inputs:\t\t%d\n", temp_int);
       MdcGetStructGD(fi, (unsigned)temp_int);
       break;
     case MDC_CONC_HDR_GATE_BINS:
       conc_get_int_int_float_float(line, &return_code, &temp_int, &temp_int2, &temp_float, &temp_float2);
       if (MDC_INFO) {
-	MdcPrntScrn("Number of Bins for Gate %d:\t%d\n", temp_int, temp_int2);
-	MdcPrntScrn("     min/max gate cycle:\t%5.3f/%5.3f\n", temp_float, temp_float2);
+        MdcPrntScrn("Number of Bins for Gate %d:\t%d\n", temp_int, temp_int2);
+        MdcPrntScrn("     min/max gate cycle:\t%5.3f/%5.3f\n", temp_float, temp_float2);
       }
       if (fi->gdata == NULL)
-	return("CONC gate_inputs line must preceed gate_bins line");
+        return("CONC gate_inputs line must preceed gate_bins line");
       if (temp_int >= fi->gatednr)
-	return("CONC more gates found then specified in gate_inputs line");
+        return("CONC more gates found then specified in gate_inputs line");
       gd = &(fi->gdata[temp_int]);
       gd->nr_projections = temp_int2;
       gd->window_low = temp_float*1000.;
       gd->window_high = temp_float*1000.;
       if (fi->dim[5] == 0)
-	fi->dim[5] = temp_int2;
+        fi->dim[5] = temp_int2;
       else
-	fi->dim[5]*=temp_int2;
+        fi->dim[5]*=temp_int2;
       fi->dim[4]/=temp_int2; /* Concorde sets frames = total gates */
       break;
     case MDC_CONC_HDR_GATE_DESCRIPTION:
       conc_get_int_string(line, &return_code, &temp_int, &temp_string);
       if (MDC_INFO) 
-	MdcPrntScrn("Gate %d description:\t\t%s\n", temp_int, temp_string);
+        MdcPrntScrn("Gate %d description:\t\t%s\n", temp_int, temp_string);
       MdcFree(temp_string);
       break;
     case MDC_CONC_HDR_SUBJECT_IDENTIFIER:
@@ -1535,7 +1535,7 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
                     temp_int, MdcConcSubjectOrientationNames[temp_int]);
       switch(temp_int) {
       case MDC_CONC_SUBJECT_ORIENTATION_FEET_PRONE:
-        fi->pat_slice_orient=MDC_SUPINE_FEETFIRST_TRANSAXIAL;
+        fi->pat_slice_orient=MDC_PRONE_FEETFIRST_TRANSAXIAL;
         break;
       case MDC_CONC_SUBJECT_ORIENTATION_HEAD_PRONE:
         fi->pat_slice_orient=MDC_PRONE_HEADFIRST_TRANSAXIAL;
@@ -1543,22 +1543,24 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
       case MDC_CONC_SUBJECT_ORIENTATION_FEET_SUPINE:
         fi->pat_slice_orient=MDC_SUPINE_FEETFIRST_TRANSAXIAL;
         break;
-      case MDC_CONC_SUBJECT_ORIENTATION_FEET_RIGHT:
+      case MDC_CONC_SUBJECT_ORIENTATION_HEAD_SUPINE:
         fi->pat_slice_orient=MDC_SUPINE_HEADFIRST_SAGITTAL;
         break;
+      case MDC_CONC_SUBJECT_ORIENTATION_FEET_RIGHT:
+        fi->pat_slice_orient=MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL;
+        break;
       case MDC_CONC_SUBJECT_ORIENTATION_HEAD_RIGHT:
-        fi->pat_slice_orient=MDC_SUPINE_FEETFIRST_SAGITTAL;
+        fi->pat_slice_orient=MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL;
         break;
       case MDC_CONC_SUBJECT_ORIENTATION_FEET_LEFT:
-        fi->pat_slice_orient=MDC_SUPINE_FEETFIRST_SAGITTAL;
+        fi->pat_slice_orient=MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL;
         break;
       case MDC_CONC_SUBJECT_ORIENTATION_HEAD_LEFT:
-        fi->pat_slice_orient=MDC_SUPINE_HEADFIRST_SAGITTAL;
+        fi->pat_slice_orient=MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL;
         break;
-      case MDC_CONC_SUBJECT_ORIENTATION_HEAD_SUPINE:
       case MDC_CONC_SUBJECT_ORIENTATION_UNKNOWN:
       default:
-        fi->pat_slice_orient=MDC_SUPINE_HEADFIRST_TRANSAXIAL;
+        fi->pat_slice_orient=MDC_UNKNOWN;
         break;
       }
       break;
@@ -1823,10 +1825,10 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
         if (temp_int != 0) return("CONC Can't handle multiple bed files");
         break;
       case MDC_CONC_BLOCK_BED_OFFSET:
-	temp_float = 10*conc_get_float(line, &return_code);
+        temp_float = 10*conc_get_float(line, &return_code);
         if (MDC_INFO)
           MdcPrntScrn("\tBed offset (mm):\t%5.3f\n", temp_float);
-	bd->hoffset = temp_float;
+        bd->hoffset = temp_float;
         break;
       case MDC_CONC_BLOCK_ENDING_BED_OFFSET:
         if (MDC_INFO)
@@ -1834,10 +1836,10 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
                       ,10*conc_get_float(line, &return_code));
         break;
       case MDC_CONC_BLOCK_VERTICAL_BED_OFFSET:
-	temp_float = 10*conc_get_float(line, &return_code);
+        temp_float = 10*conc_get_float(line, &return_code);
         if (MDC_INFO)
           MdcPrntScrn("\tBed vert. offset (mm):\t%5.3f\n", temp_float);
-	bd->voffset = temp_float;
+        bd->voffset = temp_float;
         break;
       case MDC_CONC_BLOCK_DATA_FILE_POINTER:
         conc_get_Int32_Int32(line, &return_code, &high_file_pointer
@@ -1914,7 +1916,7 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
       first_plane->load_location = high_file_pointer*INT_MAX + low_file_pointer;
 #else /* LONG_4BYTE */
       /* since the fseek command uses long, we can't use the value of
-	 high_file_pointer in calculating where to fseek.  */
+         high_file_pointer in calculating where to fseek.  */
       if (high_file_pointer != 0) failed_to_read_64_bit = MDC_YES; 
       first_plane->load_location = low_file_pointer;
 #endif
@@ -1938,7 +1940,7 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
         plane->pixel_xsize = first_plane->pixel_xsize;
         plane->pixel_ysize = first_plane->pixel_ysize;
         plane->recon_scale = first_plane->recon_scale;
-	plane->load_location = first_plane->load_location+i_plane*plane_bytes;
+        plane->load_location = first_plane->load_location+i_plane*plane_bytes;
       }
     }
   } /* i_frame */
@@ -2172,7 +2174,7 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
   for (i_dim=1;i_dim<=6;i_dim++) dimensions += (fi->dim[i_dim] > 1) ? 1 : 0;
   fprintf(fi->ofp, "#\n%s %d\n"
                  , MdcConcHdrValueNames[MDC_CONC_HDR_NUMBER_OF_DIMENSIONS]
-  	         , 3); /* dimension is always 3... regardless of dynamic or gated */
+                   , 3); /* dimension is always 3... regardless of dynamic or gated */
   fprintf(fi->ofp, "#\n%s %d\n", MdcConcHdrValueNames[MDC_CONC_HDR_X_DIMENSION]
                 , fi->dim[1]);
   fprintf(fi->ofp, "#\n%s %d\n", MdcConcHdrValueNames[MDC_CONC_HDR_Y_DIMENSION]
@@ -2180,7 +2182,7 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
   fprintf(fi->ofp, "#\n%s %d\n", MdcConcHdrValueNames[MDC_CONC_HDR_Z_DIMENSION]
                 , fi->dim[3]);
   fprintf(fi->ofp, "#\n%s %d\n", MdcConcHdrValueNames[MDC_CONC_HDR_W_DIMENSION]
-  	        , 1); /* not sure what this is used for... */
+                  , 1); /* not sure what this is used for... */
   filter_type = 0;
   for (i_filter_type=0;i_filter_type<MDC_CONC_NUM_FILTER_TYPES;i_filter_type++)
     if (strcmp(MdcConcFilterTypeNames[i_filter_type], fi->filter_type) == 0)
@@ -2195,7 +2197,7 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
                 , MdcConcHdrValueNames[MDC_CONC_HDR_RECON_ALGORITHM]
                 , MDC_CONC_RECON_UNKNOWN);
   fprintf(fi->ofp, "#\n%s %d\n"
-	        , MdcConcHdrValueNames[MDC_CONC_HDR_DECAY_CORRECTION_APPLIED]
+                , MdcConcHdrValueNames[MDC_CONC_HDR_DECAY_CORRECTION_APPLIED]
                 , fi->decay_corrected);
   fprintf(fi->ofp, "#\n%s %g\n", MdcConcHdrValueNames[MDC_CONC_HDR_PIXEL_SIZE]
                 , fi->pixdim[1]/10.0);
@@ -2234,16 +2236,16 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
                 ,  1.0);
 
   fprintf(fi->ofp, "#\n%s %d\n"
-  	        ,  MdcConcHdrValueNames[MDC_CONC_HDR_GATE_INPUTS]
-	        ,  fi->gatednr);
+                  ,  MdcConcHdrValueNames[MDC_CONC_HDR_GATE_INPUTS]
+                ,  fi->gatednr);
   for (i_gate=0; i_gate < fi->gatednr; i_gate++) {
     gd = &(fi->gdata[i_gate]);
     fprintf(fi->ofp, "#\n%s %d %1.0f %g %g\n"
-	           ,  MdcConcHdrValueNames[MDC_CONC_HDR_GATE_BINS]
-	           ,  i_gate
-	           ,  gd->nr_projections
-	           ,  gd->window_low/1000.
-	           ,  gd->window_high/1000.);
+                   ,  MdcConcHdrValueNames[MDC_CONC_HDR_GATE_BINS]
+                   ,  i_gate
+                   ,  gd->nr_projections
+                   ,  gd->window_low/1000.
+                   ,  gd->window_high/1000.);
   }
 
   fprintf(fi->ofp, "#\n%s %d\n"
@@ -2279,21 +2281,21 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
 
         fprintf(fi->ofp, "#\n%s %d\n"
                       , MdcConcBlockValueNames[MDC_CONC_BLOCK_FRAME], i_frame+i_gate*fi->dim[4]);
-	/* Concorde's ASIPro program requires the event_type entry on gated data for some reason... */
-	fprintf(fi->ofp, "#\n%s %d\n"
-		      , MdcConcBlockValueNames[MDC_CONC_BLOCK_EVENT_TYPE], MDC_CONC_EVENT_UNKNOWN);
+        /* Concorde's ASIPro program requires the event_type entry on gated data for some reason... */
+        fprintf(fi->ofp, "#\n%s %d\n"
+                      , MdcConcBlockValueNames[MDC_CONC_BLOCK_EVENT_TYPE], MDC_CONC_EVENT_UNKNOWN);
         fprintf(fi->ofp, "#\n%s %d\n"
                       , MdcConcBlockValueNames[MDC_CONC_BLOCK_GATE], i_gate);
         fprintf(fi->ofp, "#\n%s %d\n"
                       , MdcConcBlockValueNames[MDC_CONC_BLOCK_BED], i_bed);
-	if (bd != NULL) {
-	  fprintf(fi->ofp, "#\n%s %g\n"
-		         , MdcConcBlockValueNames[MDC_CONC_BLOCK_BED_OFFSET]
-		         , bd->hoffset/10.);
-	  fprintf(fi->ofp, "#\n%s %g\n"
-		         , MdcConcBlockValueNames[MDC_CONC_BLOCK_VERTICAL_BED_OFFSET]
-   		         , bd->voffset/10.);
-	}
+        if (bd != NULL) {
+          fprintf(fi->ofp, "#\n%s %g\n"
+                         , MdcConcBlockValueNames[MDC_CONC_BLOCK_BED_OFFSET]
+                         , bd->hoffset/10.);
+          fprintf(fi->ofp, "#\n%s %g\n"
+                         , MdcConcBlockValueNames[MDC_CONC_BLOCK_VERTICAL_BED_OFFSET]
+                            , bd->voffset/10.);
+        }
         fprintf(fi->ofp, "#\n#\tData file offset to start of data," \
                         " two 32 bit signed ints\n");
         fprintf(fi->ofp, "%s %d %d\n"
@@ -2316,7 +2318,7 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
             low_file_pointer = write_length - (INT_MAX-low_file_pointer);
           } else
             low_file_pointer += write_length;
-	  
+          
         }
         
         if (first_plane->rescaled) {
@@ -2332,11 +2334,11 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
                         , MdcConcBlockValueNames[MDC_CONC_BLOCK_SCALE_FACTOR]
                         , first_plane->rescale_slope);
         }
-	/* Concorde's ASIPro program requires the dead time correction entry on gated data.... */
-	fprintf(fi->ofp, "#\n# Not 1.0, Unknown\n%s %g\n"
-		      , MdcConcBlockValueNames[MDC_CONC_BLOCK_DEADTIME_CORRECTION]
-		      , 1.0);
-	/* Concorde's ASIPro program requires the decay correction entry on gated data.... */
+        /* Concorde's ASIPro program requires the dead time correction entry on gated data.... */
+        fprintf(fi->ofp, "#\n# Not 1.0, Unknown\n%s %g\n"
+                      , MdcConcBlockValueNames[MDC_CONC_BLOCK_DEADTIME_CORRECTION]
+                      , 1.0);
+        /* Concorde's ASIPro program requires the decay correction entry on gated data.... */
         {
           float num_half_lifes = 0.;
 
@@ -2370,10 +2372,10 @@ const char *MdcSaveCONC(FILEINFO *fi)
     for (i_gate = 0; i_gate < fi->dim[5]; i_gate++) {
       for (i_frame= 0; i_frame < fi->dim[4]; i_frame++) {
         for (i_plane = 0; i_plane < fi->dim[3]; i_plane++, img++) {
-	  return_string = MdcSavePlaneCONC(fi, img);
-	  if (return_string != NULL) return(return_string);
+          return_string = MdcSavePlaneCONC(fi, img);
+          if (return_string != NULL) return(return_string);
 
-	}
+        }
       }
     }
   }
@@ -2472,10 +2474,10 @@ const char *MdcWriteCONC(FILEINFO *fi)
             MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->dim[3],NULL);
           }
 
-	  return_string = MdcSavePlaneCONC(fi, img);
-	  if (return_string != NULL) return(return_string);
+          return_string = MdcSavePlaneCONC(fi, img);
+          if (return_string != NULL) return(return_string);
 
-	}
+        }
       }
     }
   }
