@@ -11,7 +11,7 @@
  *                MdcDebugPrint()    - Print MDC_MY_DEBUG info             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-debug.c,v 1.56 2005/05/16 07:35:00 enlf Exp $
+/* $Id: m-debug.c,v 1.58 2005/12/18 09:50:13 enlf Exp $
  */
 
 /*
@@ -127,6 +127,10 @@ void MdcPrintFI(FILEINFO *fi)
   MdcPrntScrn("glmax              : %+e\n",fi->glmax);
   MdcPrntScrn("qglmin             : %+e\n",fi->qglmin);
   MdcPrntScrn("qglmax             : %+e\n",fi->qglmax);
+  MdcPrntScrn("contrast_remapped  : %hd ",fi->contrast_remapped);
+  MdcPrintYesNo(fi->contrast_remapped);
+  MdcPrntScrn("window_centre      : %g\n",fi->window_centre);
+  MdcPrntScrn("window_width       : %g\n",fi->window_width);
   MdcPrntScrn("slice_projection   : %d (= %s)\n",fi->slice_projection,
                                MdcGetStrSlProjection(fi->slice_projection));
   MdcPrntScrn("pat_slice_orient   : %d (= %s)\n",fi->pat_slice_orient,
