@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-defs.h,v 1.47 2005/05/16 07:35:00 enlf Exp $
+/* $Id: m-defs.h,v 1.48 2005/11/17 22:28:32 enlf Exp $
  */
 
 /*
@@ -189,8 +189,10 @@
 #define MDC_FEET         6
 
 /* patient rotation */
-#define MDC_SUPINE      1             /* on the back            */
-#define MDC_PRONE       2             /* on the face            */
+#define MDC_SUPINE            1       /* on the back            */
+#define MDC_PRONE             2       /* on the face            */
+#define MDC_DECUBITUS_RIGHT   3       /* on the right side      */
+#define MDC_DECUBITUS_LEFT    4       /* on the left side       */
 
 /* patient orientation */
 #define MDC_HEADFIRST   1             /* head first in scanner  */
@@ -204,20 +206,31 @@
 #define MDC_CORONAL     3             /* _|_ device ; // ground */
 
 /* patient/slice combined */
-#define MDC_SUPINE_HEADFIRST_TRANSAXIAL  1
-#define MDC_SUPINE_HEADFIRST_SAGITTAL    2
-#define MDC_SUPINE_HEADFIRST_CORONAL     3
-#define MDC_SUPINE_FEETFIRST_TRANSAXIAL  4
-#define MDC_SUPINE_FEETFIRST_SAGITTAL    5
-#define MDC_SUPINE_FEETFIRST_CORONAL     6
-#define MDC_PRONE_HEADFIRST_TRANSAXIAL   7
-#define MDC_PRONE_HEADFIRST_SAGITTAL     8
-#define MDC_PRONE_HEADFIRST_CORONAL      9
-#define MDC_PRONE_FEETFIRST_TRANSAXIAL  10
-#define MDC_PRONE_FEETFIRST_SAGITTAL    11
-#define MDC_PRONE_FEETFIRST_CORONAL     12
-
-#define MDC_MAX_ORIENT                  13     /* total orientations + 1 */
+#define MDC_SUPINE_HEADFIRST_TRANSAXIAL           1
+#define MDC_SUPINE_HEADFIRST_SAGITTAL             2
+#define MDC_SUPINE_HEADFIRST_CORONAL              3
+#define MDC_SUPINE_FEETFIRST_TRANSAXIAL           4
+#define MDC_SUPINE_FEETFIRST_SAGITTAL             5
+#define MDC_SUPINE_FEETFIRST_CORONAL              6
+#define MDC_PRONE_HEADFIRST_TRANSAXIAL            7
+#define MDC_PRONE_HEADFIRST_SAGITTAL              8
+#define MDC_PRONE_HEADFIRST_CORONAL               9
+#define MDC_PRONE_FEETFIRST_TRANSAXIAL           10
+#define MDC_PRONE_FEETFIRST_SAGITTAL             11
+#define MDC_PRONE_FEETFIRST_CORONAL              12
+#define MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL 13
+#define MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   14
+#define MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    15
+#define MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL 16
+#define MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   17
+#define MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    18
+#define MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL  19
+#define MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    20
+#define MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     21
+#define MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL  22
+#define MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    23
+#define MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     24
+#define MDC_MAX_ORIENT                           25 /* total orientations + 1 */
 
 /* detector rotation */
 #define MDC_ROTATION_CW   1   /* clockwise               */
