@@ -18,7 +18,7 @@
  *                - Mosaic support     - Roland Marcus Rutschmann          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-dicm.c,v 1.167 2005/05/16 07:35:00 enlf Exp $
+/* $Id: m-dicm.c,v 1.170 2005/12/16 23:43:26 enlf Exp $
  */
 
 /*
@@ -71,10 +71,6 @@
 #define ICOL 1
 
 /* extra stuff for reading DICOM */
-static void MdcDicomFixType(IMG_DATA *id, Uint32 nr, double wc, double ww
-, double rs, double ri);
-static char *MdcDicomContrast(IMG_DATA *id, Uint32 nr, double wc, double ww
-, double rs, double ri);
 static void MdcDicomInvert(IMG_DATA *id);
 static char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom
 , IMAGE *image, Uint32 number);
@@ -150,79 +146,6 @@ int MdcCheckDICM(FILEINFO *fi)
    return(MDC_FRMT_DICM);
 }
 
-static void MdcDicomFixType(IMG_DATA *id, Uint32 nr, double wc, double ww, double rs, double ri)
-{
-  Int16 newtype = id->type;
-
-  /* rescale window center/width towards pixel values */
-  wc = (wc - ri) / rs;
-  ww = (ww / rs);
-
-  /* auto correct bad unsigned types <=> negative contrast window */
-  if ((wc - 0.5 - ((ww - 1.) / 2.)) < 0.) {
-    switch (id->type) {
-      case  BIT8_U: newtype =  BIT8_S;
-          break;
-      case BIT16_U: newtype = BIT16_S;
-          break;
-      case BIT32_U: newtype = BIT32_S;
-          break;
-      case BIT64_U: newtype = BIT64_S;
-          break;
-    }
-  }
-
-  /* give warning once */
-  if ((newtype != id->type) && (nr == 0)) {
-    MdcPrntWarn("DICM Fix wrong unsigned pixel type");
-  }
-
-  /* fix pixel type */
-  id->type = newtype;
-
-}
-
-/* see also DICOM standards: PS 3.3 - 2001 Page 505 */
-char *MdcDicomContrast(IMG_DATA *id, Uint32 nr, double wc, double ww, double rs, double ri) 
-{
-   double xval, yval;
-   double ymax, ymin;
-   Uint8 *pixel;
-   Uint32 i, n;
-   Int16 type = id->type;
-
-   /* rescale window center/width towards pixel values */
-   wc = (wc - ri) / rs;
-   ww = (ww / rs);
-
-   /* prepare range values: [0 -> +max] */
-   ymin = 0.; 
-   ymax = 255.;
-
-   n = id->width * id->height;
-   for (pixel=id->buf, i=0; i<n; i++, pixel+=MdcType2Bytes(type)) {
-
-      /* get pixel value */
-      xval = MdcGetDoublePixel(pixel,type);
-
-      /* apply window center/width */
-      if ( xval <= wc - 0.5 - ((ww-1.)/2.)) {
-        yval = ymin; 
-      }else if ( xval > wc - 0.5 + ((ww-1.)/2.)) {
-        yval = ymax;
-      }else{
-        yval = ((((xval-(wc-0.5))/(ww-1.))+0.5) * (ymax-ymin)) + ymin;
-      }
-
-      /* put value back in buffer, already fit for original pixel type */
-      MdcPutDoublePixel(pixel,yval,type);
-
-   }
-
-   return(NULL);
-
-}
-
 void MdcDicomInvert(IMG_DATA *id)
 {
    double pixvalue;
@@ -261,31 +184,6 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
   double wc, ww;
   char *msg=NULL;
 
-  /* handle window center/width */
-  if (MDC_FORCE_CONTRAST == MDC_YES) {
-    /* apply user specified values */
-    wc = (double)mdc_cw_center;
-    ww = (double)mdc_cw_width;
-  }else{
-    /* apply file specified values */
-    wc = (double)dicom->cw_center;
-    ww = (double)dicom->cw_width;
-  }
-
-  /* handle rescale slope and intercept */
-  if (MDC_FORCE_RESCALE == MDC_YES) {
-    /* apply user specified values */
-    rs = (double)mdc_si_slope;
-    ri = (double)mdc_si_intercept;
-  }else{
-    /* apply file specified values */
-    rs = (double)dicom->si_slope;
-    ri = (double)dicom->si_intercept; 
-  }
-
-  /* prevent division by zero */
-  if (rs == 0.) rs = 1.;
-
   for (img=0, i=0; i<number; i++) {
      pimg = &image[i];
      for (f=0; f<image[i].frames; f++) {
@@ -300,8 +198,8 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
         id->bits   = MdcType2Bits(id->type);
 
         if (id->type != COLRGB) {
-          id->quant_scale = (float)rs;
-          id->intercept   = (float)ri;
+          id->quant_scale = dicom->si_slope;
+          id->intercept   = dicom->si_intercept;
         }
 
         bytes = id->width*id->height*MdcType2Bytes(id->type);
@@ -365,19 +263,8 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
 
         if (id->type != COLRGB) {
 
-#if MDC_DICM_FIX_TYPE
-          /* fix pixel type */
-          MdcDicomFixType(id,img,wc,ww,rs,ri);
-#endif
-          /* contrast remapping */
-          if ((MDC_DICOM_CONTRAST == MDC_YES) && (ww != 0.0)) {
-            msg = MdcDicomContrast(id,img,wc,ww,rs,ri);
-            if (msg != NULL) {
-              MdcPrntWarn(msg);
-            }
-          }
-
           if (dicom->INVERT == MDC_YES) MdcDicomInvert(id);
+
         } 
 
         img+=1;
@@ -1122,9 +1009,9 @@ char *MdcDicomWriteG0008(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   len = strlen(mdc_dummy1);
   mdc_dicom_write_element(fi->ofp,0x0008,0x0050,len,(Uint8 *)mdc_dummy1);
 
-  strcpy(mdcbufr,MdcGetStrModality((signed)dicom->modality));
-  len = strlen(mdcbufr);
-  mdc_dicom_write_element(fi->ofp,0x0008,0x0060,len,(Uint8 *)mdcbufr);
+  pdata = MdcGetStrModality((signed)dicom->modality); /* already in mdcbufr */
+  len = strlen(pdata);
+  mdc_dicom_write_element(fi->ofp,0x0008,0x0060,len,(Uint8 *)pdata);
 
   strcpy(mdcbufr,fi->manufacturer); len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0008,0x0070,len,(Uint8 *)mdcbufr);
@@ -1213,26 +1100,6 @@ char *MdcDicomWriteG0018(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
     mdc_dicom_write_element(fi->ofp,0x0018,0x1088,len,(Uint8 *)mdcbufr);
   }
 
-  switch (fi->pat_slice_orient) {
-
-      case MDC_SUPINE_HEADFIRST_TRANSAXIAL:
-      case MDC_SUPINE_HEADFIRST_SAGITTAL   :
-      case MDC_SUPINE_HEADFIRST_CORONAL    :
-          strcpy(mdcbufr,"HFS"); break;
-      case MDC_PRONE_HEADFIRST_TRANSAXIAL :
-      case MDC_PRONE_HEADFIRST_SAGITTAL    :
-      case MDC_PRONE_HEADFIRST_CORONAL     :
-          strcpy(mdcbufr,"HFP"); break;
-      case MDC_SUPINE_FEETFIRST_TRANSAXIAL:
-      case MDC_SUPINE_FEETFIRST_SAGITTAL   :
-      case MDC_SUPINE_FEETFIRST_CORONAL    :
-          strcpy(mdcbufr,"FFS"); break;
-      case MDC_PRONE_FEETFIRST_TRANSAXIAL :
-      case MDC_PRONE_FEETFIRST_SAGITTAL    :
-      case MDC_PRONE_FEETFIRST_CORONAL     :
-          strcpy(mdcbufr,"FFP"); break;
-  }
-
   switch (dicom->modality) {
     case M_PT: break;
     default  : /* default to NM modality */
