@@ -60,7 +60,7 @@
  *                MdcAddCompressionExt()  - Add  compression extension     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-fancy.c,v 1.54 2005/05/16 07:35:00 enlf Exp $
+/* $Id: m-fancy.c,v 1.55 2005/11/17 22:28:32 enlf Exp $
  */
 
 /*
@@ -669,8 +669,8 @@ char *MdcHandlePixelList(char *list, Uint32 **cols, Uint32 **rows,
             if (((*rows)=(Uint32 *)MdcRealloc((*rows),
                         (*bt)*MDC_BUF_ITMS*sizeof(Uint32))) == NULL) {
               return("Couldn't realloc pixels row buffer");
-	    }
-	  }
+            }
+          }
           *bt+=1;
        }
 
@@ -794,29 +794,53 @@ char *MdcGetStrPatSlOrient(int patient_slice_orient)
   switch (patient_slice_orient) {
 
    case MDC_SUPINE_HEADFIRST_TRANSAXIAL:
-    strcpy(mdcbufr,"Supine;HeadFirst;Transversal"); break;
+    strcpy(mdcbufr,"Supine;HeadFirst;Transverse");  break;
    case MDC_SUPINE_HEADFIRST_SAGITTAL   : 
     strcpy(mdcbufr,"Supine;HeadFirst;Sagittal");    break;
    case MDC_SUPINE_HEADFIRST_CORONAL    : 
     strcpy(mdcbufr,"Supine;HeadFirst;Coronal");     break;
    case MDC_SUPINE_FEETFIRST_TRANSAXIAL: 
-    strcpy(mdcbufr,"Supine;FeetFirst;Transversal"); break;
+    strcpy(mdcbufr,"Supine;FeetFirst;Transverse");  break;
    case MDC_SUPINE_FEETFIRST_SAGITTAL   : 
     strcpy(mdcbufr,"Supine;FeetFirst;Sagittal");    break;
    case MDC_SUPINE_FEETFIRST_CORONAL    : 
     strcpy(mdcbufr,"Supine;FeetFirst;Coronal");     break;
    case MDC_PRONE_HEADFIRST_TRANSAXIAL : 
-    strcpy(mdcbufr,"Prone;HeadFirst;Transversal");  break;
+    strcpy(mdcbufr,"Prone;HeadFirst;Transverse");   break;
    case MDC_PRONE_HEADFIRST_SAGITTAL    : 
     strcpy(mdcbufr,"Prone;HeadFirst;Sagittal");     break;
    case MDC_PRONE_HEADFIRST_CORONAL     : 
     strcpy(mdcbufr,"Prone;HeadFirst;Coronal");      break;
    case MDC_PRONE_FEETFIRST_TRANSAXIAL : 
-    strcpy(mdcbufr,"Prone;FeetFirst;Transversal");   break;
+    strcpy(mdcbufr,"Prone;FeetFirst;Transverse");   break;
    case MDC_PRONE_FEETFIRST_SAGITTAL    : 
     strcpy(mdcbufr,"Prone;FeetFirst;Sagittal");     break;
    case MDC_PRONE_FEETFIRST_CORONAL     :
     strcpy(mdcbufr,"Prone;FeetFirst;Coronal");      break;
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
+    strcpy(mdcbufr,"DecubitusRight;HeadFirst;Transverse"); break;
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   : 
+    strcpy(mdcbufr,"DecubitusRight;HeadFirst;Sagittal");   break;
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    : 
+    strcpy(mdcbufr,"DecubitusRight;HeadFirst;Coronal");    break;
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL: 
+    strcpy(mdcbufr,"DecubitusRight;FeetFirst;Transverse"); break;
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   : 
+    strcpy(mdcbufr,"DecubitusRight;FeetFirst;Sagittal");   break;
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    : 
+    strcpy(mdcbufr,"DecubitusRight;FeetFirst;Coronal");    break;
+   case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL : 
+    strcpy(mdcbufr,"DecubitusLeft;HeadFirst;Transverse");  break;
+   case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    : 
+    strcpy(mdcbufr,"DecubitusLeft;HeadFirst;Sagittal");    break;
+   case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     : 
+    strcpy(mdcbufr,"DecubitusLeft;HeadFirst;Coronal");     break;
+   case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL : 
+    strcpy(mdcbufr,"DecubitusLeft;FeetFirst;Transverse");  break;
+   case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    : 
+    strcpy(mdcbufr,"DecubitusLeft;FeetFirst;Sagittal");    break;
+   case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     :
+    strcpy(mdcbufr,"DecubitusLeft;FeetFirst;Coronal");     break;
    default                              : 
     strcpy(mdcbufr,"Unknown");
 
@@ -844,6 +868,22 @@ char *MdcGetStrPatPos(int patient_slice_orient)
     case MDC_PRONE_FEETFIRST_SAGITTAL    :
     case MDC_PRONE_FEETFIRST_CORONAL     :
         strcpy(mdcbufr,"FFP"); break;
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL: 
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    :
+        strcpy(mdcbufr,"HFDR"); break;
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    :
+        strcpy(mdcbufr,"FFDR"); break;
+    case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
+    case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
+    case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     :
+        strcpy(mdcbufr,"HFDL"); break;
+    case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL :
+    case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    :
+    case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     :
+        strcpy(mdcbufr,"FFDL"); break;
     default                              :
         strcpy(mdcbufr,"Unknown");
   }
@@ -855,19 +895,31 @@ char *MdcGetStrPatPos(int patient_slice_orient)
 char *MdcGetStrPatOrient(int patient_slice_orient)
 {
   switch (patient_slice_orient) {
-     case MDC_SUPINE_HEADFIRST_TRANSAXIAL: strcpy(mdcbufr,"L\\P"); break;
-     case MDC_SUPINE_HEADFIRST_SAGITTAL   : strcpy(mdcbufr,"P\\F"); break;
-     case MDC_SUPINE_HEADFIRST_CORONAL    : strcpy(mdcbufr,"L\\F"); break;
-     case MDC_SUPINE_FEETFIRST_TRANSAXIAL: strcpy(mdcbufr,"R\\P"); break;
-     case MDC_SUPINE_FEETFIRST_SAGITTAL   : strcpy(mdcbufr,"P\\H"); break;
-     case MDC_SUPINE_FEETFIRST_CORONAL    : strcpy(mdcbufr,"R\\H"); break;
-     case MDC_PRONE_HEADFIRST_TRANSAXIAL : strcpy(mdcbufr,"R\\A"); break;
-     case MDC_PRONE_HEADFIRST_SAGITTAL    : strcpy(mdcbufr,"A\\F"); break;
-     case MDC_PRONE_HEADFIRST_CORONAL     : strcpy(mdcbufr,"R\\F"); break;
-     case MDC_PRONE_FEETFIRST_TRANSAXIAL : strcpy(mdcbufr,"L\\A"); break;
-     case MDC_PRONE_FEETFIRST_SAGITTAL    : strcpy(mdcbufr,"A\\H"); break;
-     case MDC_PRONE_FEETFIRST_CORONAL     : strcpy(mdcbufr,"L\\H"); break;
-     default                              : strcpy(mdcbufr,"Unknown");
+    case MDC_SUPINE_HEADFIRST_TRANSAXIAL: strcpy(mdcbufr,"L\\P"); break;
+    case MDC_SUPINE_HEADFIRST_SAGITTAL  : strcpy(mdcbufr,"P\\F"); break;
+    case MDC_SUPINE_HEADFIRST_CORONAL   : strcpy(mdcbufr,"L\\F"); break;
+    case MDC_SUPINE_FEETFIRST_TRANSAXIAL: strcpy(mdcbufr,"R\\P"); break;
+    case MDC_SUPINE_FEETFIRST_SAGITTAL  : strcpy(mdcbufr,"P\\H"); break;
+    case MDC_SUPINE_FEETFIRST_CORONAL   : strcpy(mdcbufr,"R\\H"); break;
+    case MDC_PRONE_HEADFIRST_TRANSAXIAL : strcpy(mdcbufr,"R\\A"); break;
+    case MDC_PRONE_HEADFIRST_SAGITTAL   : strcpy(mdcbufr,"A\\F"); break;
+    case MDC_PRONE_HEADFIRST_CORONAL    : strcpy(mdcbufr,"R\\F"); break;
+    case MDC_PRONE_FEETFIRST_TRANSAXIAL : strcpy(mdcbufr,"L\\A"); break;
+    case MDC_PRONE_FEETFIRST_SAGITTAL   : strcpy(mdcbufr,"A\\H"); break;
+    case MDC_PRONE_FEETFIRST_CORONAL    : strcpy(mdcbufr,"L\\H"); break;
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL: strcpy(mdcbufr,"P\\R");break;
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL  : strcpy(mdcbufr,"L\\F");break;
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL   : strcpy(mdcbufr,"P\\F");break;
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL: strcpy(mdcbufr,"A\\R");break;
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL  : strcpy(mdcbufr,"L\\H");break;
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL   : strcpy(mdcbufr,"A\\H");break;
+    case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL : strcpy(mdcbufr,"A\\L");break;
+    case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL   : strcpy(mdcbufr,"R\\F");break;
+    case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL    : strcpy(mdcbufr,"A\\F");break;
+    case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL : strcpy(mdcbufr,"P\\L");break;
+    case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL   : strcpy(mdcbufr,"R\\H");break;
+    case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL    : strcpy(mdcbufr,"P\\H");break;
+    default                              : strcpy(mdcbufr,"Unknown");
   }
 
   return(mdcbufr);
@@ -876,20 +928,32 @@ char *MdcGetStrPatOrient(int patient_slice_orient)
 char *MdcGetStrSliceOrient(int patient_slice_orient)
 {
   switch (patient_slice_orient) {
-     case MDC_SUPINE_HEADFIRST_TRANSAXIAL:
-     case MDC_PRONE_HEADFIRST_TRANSAXIAL :
-     case MDC_SUPINE_FEETFIRST_TRANSAXIAL:
-     case MDC_PRONE_FEETFIRST_TRANSAXIAL :
+     case MDC_SUPINE_HEADFIRST_TRANSAXIAL         :
+     case MDC_PRONE_HEADFIRST_TRANSAXIAL          :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
+     case MDC_SUPINE_FEETFIRST_TRANSAXIAL         :
+     case MDC_PRONE_FEETFIRST_TRANSAXIAL          :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL :
       strcpy(mdcbufr,"Transverse"); break;
-     case MDC_SUPINE_HEADFIRST_SAGITTAL   :
-     case MDC_PRONE_HEADFIRST_SAGITTAL    :
-     case MDC_SUPINE_FEETFIRST_SAGITTAL   :
-     case MDC_PRONE_FEETFIRST_SAGITTAL    :
+     case MDC_SUPINE_HEADFIRST_SAGITTAL         :
+     case MDC_PRONE_HEADFIRST_SAGITTAL          :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL :
+     case MDC_SUPINE_FEETFIRST_SAGITTAL         :
+     case MDC_PRONE_FEETFIRST_SAGITTAL          :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL :
       strcpy(mdcbufr,"Sagittal");  break;
-     case MDC_SUPINE_HEADFIRST_CORONAL    :
-     case MDC_PRONE_HEADFIRST_CORONAL     :
-     case MDC_SUPINE_FEETFIRST_CORONAL    :
-     case MDC_PRONE_FEETFIRST_CORONAL     :
+     case MDC_SUPINE_HEADFIRST_CORONAL         :
+     case MDC_PRONE_HEADFIRST_CORONAL          :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL :
+     case MDC_SUPINE_FEETFIRST_CORONAL         :
+     case MDC_PRONE_FEETFIRST_CORONAL          :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
       strcpy(mdcbufr,"Coronal");   break;
      default                              : 
       strcpy(mdcbufr,"unknown");
@@ -990,22 +1054,34 @@ int MdcGetIntSliceOrient(int patient_slice_orient)
   int slice_orient;
 
   switch (patient_slice_orient) {
-     case MDC_SUPINE_HEADFIRST_TRANSAXIAL :
-     case MDC_PRONE_HEADFIRST_TRANSAXIAL  :
-     case MDC_SUPINE_FEETFIRST_TRANSAXIAL :
-     case MDC_PRONE_FEETFIRST_TRANSAXIAL  :
+     case MDC_SUPINE_HEADFIRST_TRANSAXIAL         :
+     case MDC_PRONE_HEADFIRST_TRANSAXIAL          :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
+     case MDC_SUPINE_FEETFIRST_TRANSAXIAL         :
+     case MDC_PRONE_FEETFIRST_TRANSAXIAL          :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL :
       slice_orient = MDC_TRANSAXIAL;
       break;
-     case MDC_SUPINE_HEADFIRST_SAGITTAL   :
-     case MDC_PRONE_HEADFIRST_SAGITTAL    :
-     case MDC_SUPINE_FEETFIRST_SAGITTAL   :
-     case MDC_PRONE_FEETFIRST_SAGITTAL    :
+     case MDC_SUPINE_HEADFIRST_SAGITTAL         :
+     case MDC_PRONE_HEADFIRST_SAGITTAL          :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL :
+     case MDC_SUPINE_FEETFIRST_SAGITTAL         :
+     case MDC_PRONE_FEETFIRST_SAGITTAL          :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL :
       slice_orient = MDC_SAGITTAL;
       break;
-     case MDC_SUPINE_HEADFIRST_CORONAL    :
-     case MDC_PRONE_HEADFIRST_CORONAL     :
-     case MDC_SUPINE_FEETFIRST_CORONAL    :
-     case MDC_PRONE_FEETFIRST_CORONAL     :
+     case MDC_SUPINE_HEADFIRST_CORONAL         :
+     case MDC_PRONE_HEADFIRST_CORONAL          :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL :
+     case MDC_SUPINE_FEETFIRST_CORONAL         :
+     case MDC_PRONE_FEETFIRST_CORONAL          :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
       slice_orient = MDC_CORONAL;
       break;
      default                              : 
