@@ -32,7 +32,6 @@
  *                MdcGetLastPathDelim() - Get pointer last path delimiter  * 
  *                MdcMySplitPath()      - Split path from filename         *
  *                MdcMyMergePath()      - Merge path to filename           *
- *                MdcNewExt()           - Give filename a new extension    *
  *                MdcNewName()          - Create new filename              *
  *                MdcAliasName()        - Create alias name based on ID's  *
  *                MdcEchoAliasName()    - Echo   alias name based on ID's  *
@@ -47,7 +46,7 @@
  *                MdcGetHeartRate()     - Get heart rate from gated data   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.c,v 1.92 2005/05/16 07:35:01 enlf Exp $ 
+/* $Id: m-files.c,v 1.96 2005/12/16 23:39:03 enlf Exp $ 
  */
 
 /*
@@ -240,6 +239,8 @@ int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi))
   /* do some requested transformations */
   msg = NULL;
   if (MDC_INFO == MDC_NO) {
+    if ((msg == NULL) && (MDC_CONTRAST_REMAP  == MDC_YES))
+      msg=MdcContrastRemap(fi);
     if ((msg == NULL) && (MDC_MAKE_SQUARE     != MDC_NO))
       msg=MdcMakeSquare(fi,MDC_MAKE_SQUARE);
     if ((msg == NULL) && (MDC_FLIP_HORIZONTAL == MDC_YES))
@@ -276,14 +277,6 @@ int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)())
   /* reset ID's rescaled stuff from any previous write */
   MdcResetIDs(fi);
 
-  /* new basename */
-  if ((XMDC_GUI == MDC_NO) && (mdcbasename != NULL)) {
-    strncpy(fi->ipath,mdcbasename,MDC_MAX_PATH);
-    fi->ipath[MDC_MAX_PATH]='\0';
-    fi->idir = NULL;
-    fi->ifname = fi->ipath;
-  }
-
   /* negative value = self made prefix */
   if (prefixnr >= 0 ) MdcPrefix(prefixnr);
 
@@ -413,14 +406,6 @@ int MdcSaveFile(FILEINFO *fi, int format, int prefixnr)
   /* reset ID's rescaled stuff from any previous write */
   MdcResetIDs(fi);
 
-  /* new basename */
-  if ((XMDC_GUI == MDC_NO) && (mdcbasename != NULL)) {
-    strncpy(fi->ipath,mdcbasename,MDC_MAX_PATH);
-    fi->ipath[MDC_MAX_PATH]='\0';
-    fi->idir = NULL;
-    fi->ifname = fi->ipath;
-  }
-
   /* negative value = self made prefix */
   if (prefixnr >= 0 ) MdcPrefix(prefixnr);
 
@@ -938,15 +923,30 @@ char *MdcGetExtension(char path[])
   return(ext);
 
 } 
-    
-    
+
 void MdcNewExt(char dest[], char *src, char *ext)
 {
-  char *p;
+  char *p, *s;
 
-  if ((src != NULL) && (src[0] != '\0'))  strcat(dest,src);
-  /* MARK: 8.3 DOS filename problem for GtkWin32 XMedCon        */ 
-  /* MARK: because full path is supplied -> removed restriction */
+  if (mdcbasename != NULL) {
+    /* forced output name/path */
+    s = MdcGetLastPathDelim(mdcbasename);
+    p = strrchr(mdcbasename,'.');
+    if (s != NULL) {
+      /* full pathname */
+      strncpy(dest,mdcbasename,MDC_MAX_PATH); dest[MDC_MAX_PATH-5]='\0';
+      if ((p != NULL) && (p < s)) {
+        /* prevent "(.)./filename" without . for extension */
+        strcat(dest,".ext");
+      }
+    }else{
+      /* single basename */
+      strncat(dest,mdcbasename,MDC_MAX_PATH);
+    }
+  }else{
+    /* default output name */
+    if ((src != NULL) && (src[0] != '\0'))  strcat(dest,src);
+  }
 
   p=(char *)strrchr(dest,'.');
 
@@ -1238,24 +1238,36 @@ void MdcFillImgPos(FILEINFO *fi, Uint32 nr, Uint32 plane, float translation)
 
    case MDC_SUPINE_HEADFIRST_TRANSAXIAL: 
    case MDC_PRONE_HEADFIRST_TRANSAXIAL :
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
+   case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
    case MDC_SUPINE_FEETFIRST_TRANSAXIAL:
    case MDC_PRONE_FEETFIRST_TRANSAXIAL :
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
+   case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL :
     id->image_pos_dev[0]=-(id->pixel_xsize*(float)id->width);
     id->image_pos_dev[1]=-(id->pixel_ysize*(float)id->height);
     id->image_pos_dev[2]=-((id->slice_spacing*(float)(plane+1))+translation);
     break;
    case MDC_SUPINE_HEADFIRST_SAGITTAL   :
    case MDC_PRONE_HEADFIRST_SAGITTAL    :
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL:
+   case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL :
    case MDC_SUPINE_FEETFIRST_SAGITTAL   :
    case MDC_PRONE_FEETFIRST_SAGITTAL    :
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL:
+   case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL :
     id->image_pos_dev[0]=-((id->slice_spacing*(float)(plane+1))+translation);
     id->image_pos_dev[1]=-(id->pixel_xsize*(float)id->width);
     id->image_pos_dev[2]=-(id->pixel_ysize*(float)id->height);
     break;
    case MDC_SUPINE_HEADFIRST_CORONAL    :
    case MDC_PRONE_HEADFIRST_CORONAL     :
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL:
+   case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL :
    case MDC_SUPINE_FEETFIRST_CORONAL    :
    case MDC_PRONE_FEETFIRST_CORONAL     :
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL:
+   case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
     id->image_pos_dev[0]=-(id->pixel_xsize*(float)id->width);
     id->image_pos_dev[1]=-((id->slice_spacing*(float)(plane+1))+translation);
     id->image_pos_dev[2]=-(id->pixel_ysize*(float)id->height);
@@ -1327,6 +1339,66 @@ void MdcFillImgPos(FILEINFO *fi, Uint32 nr, Uint32 plane, float translation)
     id->image_pos_pat[1]=+((id->slice_spacing*(float)(plane+1))+translation);
     id->image_pos_pat[2]=+(id->pixel_ysize*(float)id->height);
     break;
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
+    id->image_pos_pat[0]=+(id->pixel_ysize*(float)id->height);
+    id->image_pos_pat[1]=-(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[2]=-((id->slice_spacing*(float)(plane+1))+translation);
+    break;
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL:
+    id->image_pos_pat[0]=-(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[1]=-((id->slice_spacing*(float)(plane+1))+translation);
+    id->image_pos_pat[2]=-(id->pixel_ysize*(float)id->height);
+    break;
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL:
+    id->image_pos_pat[0]=+((id->slice_spacing*(float)(plane+1))+translation);
+    id->image_pos_pat[1]=-(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[2]=-(id->pixel_ysize*(float)id->height);
+    break;
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
+    id->image_pos_pat[0]=+(id->pixel_ysize*(float)id->height);
+    id->image_pos_pat[1]=+(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[2]=+((id->slice_spacing*(float)(plane+1))+translation);
+    break;
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL:
+    id->image_pos_pat[0]=+(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[1]=+((id->slice_spacing*(float)(plane+1))+translation);
+    id->image_pos_pat[2]=+(id->pixel_ysize*(float)id->height);
+    break;
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL:
+    id->image_pos_pat[0]=+((id->slice_spacing*(float)(plane+1))+translation);
+    id->image_pos_pat[1]=+(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[2]=+(id->pixel_ysize*(float)id->height);
+    break;
+   case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
+    id->image_pos_pat[0]=-(id->pixel_ysize*(float)id->height);
+    id->image_pos_pat[1]=+(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[2]=-((id->slice_spacing*(float)(plane+1))+translation);
+    break;
+   case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL :
+    id->image_pos_pat[0]=-(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[1]=+((id->slice_spacing*(float)(plane+1))+translation);
+    id->image_pos_pat[2]=-(id->pixel_ysize*(float)id->height);
+    break;
+   case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL :
+    id->image_pos_pat[0]=-((id->slice_spacing*(float)(plane+1))+translation);
+    id->image_pos_pat[1]=+(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[2]=-(id->pixel_ysize*(float)id->height);
+    break;
+   case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL :
+    id->image_pos_pat[0]=-(id->pixel_ysize*(float)id->height);
+    id->image_pos_pat[1]=-(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[2]=+((id->slice_spacing*(float)(plane+1))+translation);
+    break;
+   case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL :
+    id->image_pos_pat[0]=+(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[0]=-((id->slice_spacing*(float)(plane+1))+translation);
+    id->image_pos_pat[2]=+(id->pixel_ysize*(float)id->height);
+    break;
+   case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
+    id->image_pos_pat[0]=-((id->slice_spacing*(float)(plane+1))+translation);
+    id->image_pos_pat[1]=-(id->pixel_xsize*(float)id->width);
+    id->image_pos_pat[2]=+(id->pixel_ysize*(float)id->height);
+    break;
    default                              : { } /* do nothing */
   }
 }
@@ -1340,8 +1412,12 @@ void MdcFillImgOrient(FILEINFO *fi, Uint32 nr)
   switch (fi->pat_slice_orient) {
      case MDC_SUPINE_HEADFIRST_TRANSAXIAL:
      case MDC_PRONE_HEADFIRST_TRANSAXIAL :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
      case MDC_SUPINE_FEETFIRST_TRANSAXIAL:
      case MDC_PRONE_FEETFIRST_TRANSAXIAL :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL :
          id->image_orient_dev[0]=+1.0;    id->image_orient_dev[3]=+0.0;
          id->image_orient_dev[1]=-0.0;    id->image_orient_dev[4]=+1.0;
          id->image_orient_dev[2]=+0.0;    id->image_orient_dev[5]=-0.0;
@@ -1349,8 +1425,12 @@ void MdcFillImgOrient(FILEINFO *fi, Uint32 nr)
 
      case MDC_SUPINE_HEADFIRST_SAGITTAL   :
      case MDC_PRONE_HEADFIRST_SAGITTAL    :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL :
      case MDC_SUPINE_FEETFIRST_SAGITTAL   :
      case MDC_PRONE_FEETFIRST_SAGITTAL    :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL :
          id->image_orient_dev[0]=+0.0;    id->image_orient_dev[3]=+0.0; 
          id->image_orient_dev[1]=+1.0;    id->image_orient_dev[4]=-0.0;
          id->image_orient_dev[2]=-0.0;    id->image_orient_dev[5]=-1.0;
@@ -1358,8 +1438,12 @@ void MdcFillImgOrient(FILEINFO *fi, Uint32 nr)
 
      case MDC_SUPINE_HEADFIRST_CORONAL    :
      case MDC_PRONE_HEADFIRST_CORONAL     :
+     case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL:
+     case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL :
      case MDC_SUPINE_FEETFIRST_CORONAL    :
      case MDC_PRONE_FEETFIRST_CORONAL     :
+     case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL:
+     case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
          id->image_orient_dev[0]=+1.0;    id->image_orient_dev[3]=+0.0; 
          id->image_orient_dev[1]=-0.0;    id->image_orient_dev[4]=-0.0;
          id->image_orient_dev[2]=+0.0;    id->image_orient_dev[5]=-1.0;
@@ -1432,6 +1516,24 @@ void MdcFillImgOrient(FILEINFO *fi, Uint32 nr)
          id->image_orient_pat[1]=-0.0;    id->image_orient_pat[4]=+0.0;
          id->image_orient_pat[2]=+0.0;    id->image_orient_pat[5]=+1.0;
          break;
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL:
+         id->image_orient_pat[0]=+1.0;    id->image_orient_pat[3]=+0.0;
+         id->image_orient_pat[1]=-0.0;    id->image_orient_pat[4]=+1.0;
+         id->image_orient_pat[2]=+0.0;    id->image_orient_pat[5]=-0.0;
+         break;
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL:
+   case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL:
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL:
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL:
+   case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL:
+   case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL :
+   case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL :
+   case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL :
+   case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL :
+   case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL :
+   case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL :
+   /* FIXME */
+   /* MdcPrntWarn("Extra code needed in %s at line %d\n", __FILE__, __LINE__);*/
    default                              : { } /* do nothing */
   }
 }
@@ -1478,6 +1580,10 @@ Int8 MdcGetPatSliceOrient(FILEINFO *fi, Uint32 i)
       patient_rotation = MDC_SUPINE;
     }else if (strstr(fi->pat_pos,"P") != NULL) {
       patient_rotation = MDC_PRONE;
+    }else if (strstr(fi->pat_pos, "DR") != NULL) {
+      patient_rotation = MDC_DECUBITUS_RIGHT;
+    }else if (strstr(fi->pat_pos, "DL") != NULL) {
+      patient_rotation = MDC_DECUBITUS_LEFT;
     }
 
     /* slice orientation */
@@ -1551,6 +1657,66 @@ Int8 MdcGetPatSliceOrient(FILEINFO *fi, Uint32 i)
                 break;
           }
           break;
+      case MDC_DECUBITUS_RIGHT:
+          switch (patient_orientation) {
+            case MDC_HEADFIRST:
+                switch (slice_orientation) {
+                  case MDC_TRANSAXIAL:
+                      pat_slice_orient=MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL;
+                      break;
+                  case MDC_SAGITTAL:
+                      pat_slice_orient=MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL;
+                      break;
+                  case MDC_CORONAL:
+                      pat_slice_orient=MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL;
+                      break;
+                }
+                break;
+            case MDC_FEETFIRST:
+                switch (slice_orientation) {
+                  case MDC_TRANSAXIAL:
+                      pat_slice_orient=MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL;
+                      break;
+                  case MDC_SAGITTAL:
+                      pat_slice_orient=MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL;
+                      break;
+                  case MDC_CORONAL:
+                      pat_slice_orient=MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL;
+                      break;
+                }
+                break;
+          }
+          break;
+      case MDC_DECUBITUS_LEFT:
+          switch (patient_orientation) {
+            case MDC_HEADFIRST:
+                switch (slice_orientation) {
+                  case MDC_TRANSAXIAL:
+                      pat_slice_orient=MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL;
+                      break;
+                  case MDC_SAGITTAL:
+                      pat_slice_orient=MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL;
+                      break;
+                  case MDC_CORONAL:
+                      pat_slice_orient=MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL;
+                      break;
+                }
+                break;
+            case MDC_FEETFIRST:
+                switch (slice_orientation) {
+                  case MDC_TRANSAXIAL:
+                      pat_slice_orient=MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL;
+                      break;
+                  case MDC_SAGITTAL:
+                      pat_slice_orient=MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL;
+                      break;
+                  case MDC_CORONAL:
+                      pat_slice_orient=MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL;
+                      break;
+                }
+                break;
+          }
+          break;
     }
 
     if (pat_slice_orient != MDC_UNKNOWN) return(pat_slice_orient);
@@ -1563,16 +1729,19 @@ Int8 MdcGetPatSliceOrient(FILEINFO *fi, Uint32 i)
   if ((i0 == -1)   && (i4 == +1))   return MDC_SUPINE_FEETFIRST_TRANSAXIAL;
   if ((i0 == -1)   && (i4 == -1))   return MDC_PRONE_HEADFIRST_TRANSAXIAL;
   if ((i0 == +1)   && (i4 == -1))   return MDC_PRONE_FEETFIRST_TRANSAXIAL;
+  /* FIXME - doesn't handle DECUBITUS positions */
 
   if ((i1 == +1)   && (i5 == -1))   return MDC_SUPINE_HEADFIRST_SAGITTAL;
   if ((i1 == +1)   && (i5 == +1))   return MDC_SUPINE_FEETFIRST_SAGITTAL;
   if ((i1 == -1)   && (i5 == -1))   return MDC_PRONE_HEADFIRST_SAGITTAL;
   if ((i1 == -1)   && (i5 == +1))   return MDC_PRONE_FEETFIRST_SAGITTAL;
+  /* FIXME - doesn't handle DECUBITUS positions */
 
   if ((i0 == +1)   && (i5 == -1))   return MDC_SUPINE_HEADFIRST_CORONAL;
   if ((i0 == -1)   && (i5 == +1))   return MDC_SUPINE_FEETFIRST_CORONAL;
   if ((i0 == -1)   && (i5 == -1))   return MDC_PRONE_HEADFIRST_CORONAL;
   if ((i0 == +1)   && (i5 == +1))   return MDC_PRONE_FEETFIRST_CORONAL;
+  /* FIXME - doesn't handle DECUBITUS positions */
 
   return(MDC_UNKNOWN);
 }
@@ -1634,6 +1803,35 @@ Int8 MdcTryPatSliceOrient(char *pat_orient)
   if (orient1 == MDC_LEFT      && orient2 == MDC_HEAD)
     return MDC_PRONE_FEETFIRST_CORONAL;
 
+  if (orient1 == MDC_POSTERIOR  && orient2 == MDC_RIGHT)
+    return MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL;
+  if (orient1 == MDC_RIGHT      && orient2 == MDC_FEET)
+    return MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL;
+  if (orient1 == MDC_POSTERIOR  && orient2 == MDC_FEET)
+    return MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL;
+
+  if (orient1 == MDC_ANTERIOR   && orient2 == MDC_RIGHT)
+    return MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL;
+  if (orient1 == MDC_RIGHT      && orient2 == MDC_HEAD)
+    return MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL;
+  if (orient1 == MDC_ANTERIOR   && orient2 == MDC_HEAD)
+    return MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL;
+
+  if (orient1 == MDC_ANTERIOR && orient2 == MDC_LEFT)
+    return MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL;
+  if (orient1 == MDC_LEFT     && orient2 == MDC_FEET)
+    return MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL;
+  if (orient1 == MDC_ANTERIOR && orient2 == MDC_FEET)
+    return MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL;
+
+  if (orient1 == MDC_POSTERIOR && orient2 == MDC_LEFT)
+    return MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL;
+  if (orient1 == MDC_LEFT       && orient2 == MDC_FEET)
+    return MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL;
+  if (orient1 == MDC_POSTERIOR  && orient2 == MDC_FEET)
+    return MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL;
+
+
   return MDC_UNKNOWN;
 }
 
