@@ -14,7 +14,7 @@
  *                MdcHandleArgs()         - Handle the arguments           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-getopt.c,v 1.123 2005/05/16 07:35:01 enlf Exp $
+/* $Id: m-getopt.c,v 1.127 2005/12/17 13:56:34 enlf Exp $
  */
 
 /*
@@ -125,7 +125,8 @@ void MdcPrintGlobalOptions(void)
   }
 
   MdcPrntScrn("\n\
-Pixels: [-n|-qs|-qc|-q] [-nf] [-b8|-b16[.12]] [-big|little]\n\
+Pixels: [-n] [-nf] [-qs|-qc|-q] [-b8|-b16[.12]] [-big|little]\n\
+        [-si=<slope>:<intercept>] [-cw=<centre>:<width>]\n\
 \n  -n, --negatives           enable negative pixels\
 \n  -nf, --norm-over-frames   normalize values over each frames\
 \n  -q, --quantitation        quantitation using all factors (-qc)\
@@ -137,6 +138,8 @@ Pixels: [-n|-qs|-qc|-q] [-nf] [-b8|-b16[.12]] [-big|little]\n\
 \n  -b16.12                   write unsigned shorts, only 12 bits used\
 \n  -big, --big-endian        write files in big    endian\
 \n  -little, --little-endian  write files in little endian\
+\n  -si                       force slope/intercept rescaling\
+\n  -cw                       force specified contrast remapping\
 \n");
   MdcPrntScrn("\n\
 Fallback Read Format: [-fb-none|-fb-anlz|-fb-conc|-fb-ecat|fb-dicom]\n\
@@ -233,14 +236,13 @@ Format Analyze: [-spm -optspm]\n\
 #if (MDC_INCLUDE_DICM || MDC_INCLUDE_ACR)
   MdcPrntScrn("\n\
 Format DICOM:\n\
-\n a) general: [-si=<slope>:<intercept>] [-cw=<center>:<width>]\n\
+\n a) general: [-cw=<center>:<width>]\n\
              [-contrast] [-gap] [-implicit] [-nometa]\n\
 \n  -contrast, --enable-contrast  enable support for contrast changes\
 \n  -gap, --spacing-true-gap      slice spacing is true gap or overlap");
   MdcPrntScrn("\
 \n  -implicit, --write-implicit   output file as implicit little endian\
 \n  -nometa, --write-without-meta output file without (part 10) meta header\
-\n  -si                           force slope/intercept rescaling\
 \n  -cw                           force window center/width contrast");
   MdcPrntScrn("\n\
 \n b) mosaic: [-mosaic | -fmosaic=<W>x<H>x<N> [-interl] [-mfixv]]\n\
@@ -497,7 +499,8 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
        continue;
      }else if ( (strcasecmp(argv[a],"-o") == 0) ||
                 (strcasecmp(argv[a],"--output-name") == 0) ) {
-       a+=1; if (a < argc) mdcbasename = argv[a];
+       a+=1;
+       if ((XMDC_GUI == MDC_NO) && (a < argc)) mdcbasename = argv[a];
        continue;
      }else if ( (strcasecmp(argv[a],"-p") == 0) ||
                 (strcasecmp(argv[a],"--print-values") == 0) ) {
@@ -623,8 +626,8 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
        sscanf(argv[a],"-si=%f:%f",&mdc_si_slope,&mdc_si_intercept);
        continue;
      }else if ( strstr(argv[a],"-cw=") != NULL ) {
-       MDC_FORCE_CONTRAST = MDC_YES; MDC_DICOM_CONTRAST = MDC_YES; 
-       sscanf(argv[a],"-cw=%f:%f",&mdc_cw_center,&mdc_cw_width);
+       MDC_FORCE_CONTRAST = MDC_YES; MDC_CONTRAST_REMAP = MDC_YES; 
+       sscanf(argv[a],"-cw=%f:%f",&mdc_cw_centre,&mdc_cw_width);
        continue;
      }else if ( (strcasecmp(argv[a],"-mosaic") == 0) ||
                 (strcasecmp(argv[a],"--enable-mosaic") == 0) ) {
@@ -656,7 +659,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
        MDC_TRUE_GAP = MDC_YES; continue;
      }else if ( (strcasecmp(argv[a],"-contrast") == 0) ||
                 (strcasecmp(argv[a],"--enable-contrast") == 0) ) {
-       MDC_DICOM_CONTRAST = MDC_YES; continue;
+       MDC_CONTRAST_REMAP = MDC_YES; continue;
      }else if ( (strcasecmp(argv[a],"-implicit") == 0) ||
                 (strcasecmp(argv[a],"--write-implicit") == 0) ) {
        MDC_DICOM_WRITE_IMPLICIT = MDC_YES; continue;
@@ -1090,6 +1093,8 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
     MdcPrntMesg("Calibration        is ON  (ECAT units=[uCi/ml])");
     if (MDC_NEGATIVE  == MDC_YES)
     MdcPrntMesg("Negative pixels    is ON");
+    if (MDC_CONTRAST_REMAP == MDC_YES)
+    MdcPrntMesg("Contrast remapping is ON");
     if (MDC_ANLZ_SPM  == MDC_YES)
     MdcPrntMesg("Analyze for SPM    is ON");
     if (MDC_DICOM_MOSAIC_ENABLED == MDC_YES)
@@ -1100,8 +1105,6 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
     MdcPrntMesg("Mosaic fix voxel   is ON");
     if (MDC_TRUE_GAP == MDC_YES) 
     MdcPrntMesg("True gap/overlap   is ON");
-    if (MDC_DICOM_CONTRAST == MDC_YES)
-    MdcPrntMesg("Contrast window    is ON");
     if (MDC_DICOM_WRITE_IMPLICIT == MDC_YES)
     MdcPrntMesg("Dicom implicit     is ON");
     if (MDC_DICOM_WRITE_NOMETA == MDC_YES)
