@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.c,v 1.67 2005/05/16 07:35:01 enlf Exp $
+/* $Id: m-global.c,v 1.68 2005/12/16 23:42:33 enlf Exp $
  */
 
 /*
@@ -113,7 +113,7 @@ float mdc_si_slope     = 1.;
 float mdc_si_intercept = 0.;
 
 /* user specified window center/width */
-float mdc_cw_center    = 0.;
+float mdc_cw_centre    = 0.;
 float mdc_cw_width     = 0.;
 
 /* predefined mosaic stamps layout */
@@ -143,7 +143,6 @@ Int8 MDC_DICOM_MOSAIC_ENABLED = MDC_NO;    /* DICOM: mosaic support enabled   */
 Int8 MDC_DICOM_MOSAIC_FORCED  = MDC_NO;    /* DICOM: mosaic preset  forced    */
 Int8 MDC_DICOM_MOSAIC_DO_INTERL = MDC_NO;  /* DICOM: mosaic forced interlaced */
 Int8 MDC_DICOM_MOSAIC_FIX_VOXEL = MDC_NO;  /* DICOM: mosaic fix voxel sizes   */
-Int8 MDC_DICOM_CONTRAST = MDC_NO;          /* DICOM: enable contrast window   */
 Int8 MDC_DICOM_WRITE_IMPLICIT = MDC_NO;    /* DICOM: write little implicit    */
 Int8 MDC_DICOM_WRITE_NOMETA = MDC_NO;      /* DICOM: write without meta header*/
 
@@ -164,6 +163,7 @@ Int8 MDC_PIXELS_PRINT_ALL = MDC_NO;     /* print    all    pix values       */
 Int8 MDC_NEGATIVE = MDC_NO;             /* allow negative pixel values      */
 Int8 MDC_QUANTIFY = MDC_NO;             /* quantitation with one factor     */
 Int8 MDC_CALIBRATE = MDC_NO;            /* quantitation with two factors    */
+Int8 MDC_CONTRAST_REMAP = MDC_NO;       /* apply contrast remapping         */
 
 Int8 MDC_DEBUG = MDC_NO;                /* give debug info                  */
 Int8 MDC_VERBOSE = MDC_NO;              /* run in verbose mode              */
