@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.h,v 1.56 2005/05/16 07:35:01 enlf Exp $
+/* $Id: m-global.h,v 1.57 2005/12/16 23:42:33 enlf Exp $
  */
 
 /*
@@ -57,7 +57,7 @@ extern char FrmtExt[MDC_MAX_FRMTS][8];
 
 extern float mdc_si_slope;
 extern float mdc_si_intercept;
-extern float mdc_cw_center;
+extern float mdc_cw_centre;
 extern float mdc_cw_width;
 
 extern Uint32 mdc_mosaic_width;
@@ -78,7 +78,6 @@ extern Int8 MDC_PADDING_MODE;
 extern Int8 MDC_ANLZ_SPM, MDC_ANLZ_OPTIONS;
 extern Int8 MDC_DICOM_MOSAIC_ENABLED, MDC_DICOM_MOSAIC_FORCED;
 extern Int8 MDC_DICOM_MOSAIC_DO_INTERL, MDC_DICOM_MOSAIC_FIX_VOXEL;
-extern Int8 MDC_DICOM_CONTRAST;
 extern Int8 MDC_DICOM_WRITE_IMPLICIT, MDC_DICOM_WRITE_NOMETA;
 extern Int8 MDC_FORCE_RESCALE;
 extern Int8 MDC_FORCE_CONTRAST;
@@ -89,6 +88,7 @@ extern Int8 MDC_INFO, MDC_INTERACTIVE, MDC_CONVERT;
 extern Int8 MDC_EXTRACT, MDC_NEGATIVE;
 extern Int8 MDC_PIXELS, MDC_PIXELS_PRINT_ALL;
 extern Int8 MDC_QUANTIFY, MDC_CALIBRATE, MDC_DEBUG;
+extern Int8 MDC_CONTRAST_REMAP;
 extern Int8 MDC_GIF_OPTIONS;
 extern Int8 MDC_MAKE_GRAY, MDC_DITHER_COLOR;
 extern Int8 MDC_VERBOSE, MDC_RENAME;
