@@ -13,7 +13,7 @@
  *                MdcResliceImages()        - Reslice image (tra,cor,sag)  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-rslice.c,v 1.23 2005/05/16 07:35:02 enlf Exp $
+/* $Id: m-rslice.c,v 1.26 2005/11/17 22:28:32 enlf Exp $
  */
 
 /*
@@ -73,20 +73,35 @@ Int8 MdcGetSliceProjection(FILEINFO *cur)
 
     switch (cur->pat_slice_orient) {
 
-      case MDC_SUPINE_HEADFIRST_TRANSAXIAL :
-      case MDC_SUPINE_FEETFIRST_TRANSAXIAL :
-      case MDC_PRONE_HEADFIRST_TRANSAXIAL  :
-      case MDC_PRONE_FEETFIRST_TRANSAXIAL  : slice_projection = MDC_TRANSAXIAL;
+      case MDC_SUPINE_HEADFIRST_TRANSAXIAL          :
+      case MDC_SUPINE_FEETFIRST_TRANSAXIAL          :
+      case MDC_PRONE_HEADFIRST_TRANSAXIAL           :
+      case MDC_PRONE_FEETFIRST_TRANSAXIAL           : 
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL  :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL  :
+	slice_projection = MDC_TRANSAXIAL;
           break; 
-      case MDC_SUPINE_HEADFIRST_SAGITTAL   :
-      case MDC_SUPINE_FEETFIRST_SAGITTAL   :
-      case MDC_PRONE_HEADFIRST_SAGITTAL    :
-      case MDC_PRONE_FEETFIRST_SAGITTAL    : slice_projection = MDC_SAGITTAL;
+      case MDC_SUPINE_HEADFIRST_SAGITTAL            :
+      case MDC_SUPINE_FEETFIRST_SAGITTAL            :
+      case MDC_PRONE_HEADFIRST_SAGITTAL             :
+      case MDC_PRONE_FEETFIRST_SAGITTAL             :        
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    :
+	slice_projection = MDC_SAGITTAL;
           break;
-      case MDC_SUPINE_HEADFIRST_CORONAL    :
-      case MDC_SUPINE_FEETFIRST_CORONAL    :
-      case MDC_PRONE_HEADFIRST_CORONAL     :
-      case MDC_PRONE_FEETFIRST_CORONAL     : slice_projection = MDC_CORONAL;
+      case MDC_SUPINE_HEADFIRST_CORONAL             :
+      case MDC_SUPINE_FEETFIRST_CORONAL             :
+      case MDC_PRONE_HEADFIRST_CORONAL              :
+      case MDC_PRONE_FEETFIRST_CORONAL              : 
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     :
+	slice_projection = MDC_CORONAL;
           break;
       default: slice_projection = MDC_TRANSAXIAL;
 
@@ -163,6 +178,66 @@ Int8 MdcGetNewPatSliceOrient(FILEINFO *cur, Int8 newproj)
               break;
         }
         break;
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL :
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
+    case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    :
+        switch (newproj) {
+          case MDC_TRANSAXIAL :
+              pat_slice_orient = MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL;
+              break;
+          case MDC_SAGITTAL   :
+              pat_slice_orient = MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL;
+              break;
+          case MDC_CORONAL    :
+              pat_slice_orient = MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL;
+              break;
+        }
+        break;
+    case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL  :
+    case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
+    case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     :
+        switch (newproj) {
+          case MDC_TRANSAXIAL:
+              pat_slice_orient = MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL;
+              break;
+          case MDC_SAGITTAL   :
+              pat_slice_orient = MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL;
+              break;
+          case MDC_CORONAL    :
+              pat_slice_orient = MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL;
+              break;
+        }
+        break;
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL :
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
+    case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    :
+        switch (newproj) {
+          case MDC_TRANSAXIAL :
+              pat_slice_orient = MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL;
+              break;
+          case MDC_SAGITTAL   :
+              pat_slice_orient = MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL;
+              break;
+          case MDC_CORONAL    :
+              pat_slice_orient = MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL;
+              break;
+        }
+        break;
+    case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL  :
+    case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    :
+    case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     :
+        switch (newproj) {
+          case MDC_TRANSAXIAL :
+              pat_slice_orient = MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL;
+              break;
+          case MDC_SAGITTAL   :
+              pat_slice_orient = MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL;
+              break;
+          case MDC_CORONAL    :
+              pat_slice_orient = MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL;
+              break;
+        }
+        break;
   }
 
   return(pat_slice_orient);
@@ -412,11 +487,21 @@ char *MdcResliceImages(FILEINFO *cur, Int8 newproj)
     MdcCleanUpFI(new); MdcFree(new) return(msg);
   }
 
-  /* remove cur, copy new, free new but not the images */
+  /* remove cur */
   MdcCleanUpFI(cur);
+
+  /* copy new -> cur */
   MdcCopyFI(cur,new,MDC_NO,MDC_YES);
-  cur->number= new->number; new->number = 0;     /* copy & mask away */
-  cur->image = new->image;  new->image  = NULL;  /* copy & mask away */
+
+  /* just rehang image pointer */
+  cur->number= new->number;
+  cur->image = new->image;
+
+  /* and mask new image pointer */
+  new->number = 0;
+  new->image  = NULL;
+
+  /* now safely remove new */
   MdcCleanUpFI(new); MdcFree(new);
 
   return(NULL);
