@@ -13,7 +13,7 @@
  *                MdcStackFiles()          - Main stack routine            *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-stack.c,v 1.29 2005/05/16 07:35:02 enlf Exp $
+/* $Id: m-stack.c,v 1.30 2005/11/17 22:28:32 enlf Exp $
  */
 
 /*
@@ -225,18 +225,30 @@ char *MdcStackSlices(void)
   if (ofi->planar == MDC_NO) {
     /* check for orthogonal slices */
     switch (ofi->pat_slice_orient) {
-      case MDC_SUPINE_HEADFIRST_SAGITTAL   :
-      case MDC_SUPINE_FEETFIRST_SAGITTAL   :
-      case MDC_PRONE_HEADFIRST_SAGITTAL    :
-      case MDC_PRONE_FEETFIRST_SAGITTAL    :
-      case MDC_SUPINE_HEADFIRST_CORONAL    :
-      case MDC_SUPINE_FEETFIRST_CORONAL    :
-      case MDC_PRONE_HEADFIRST_CORONAL     :
-      case MDC_PRONE_FEETFIRST_CORONAL     :
-      case MDC_SUPINE_HEADFIRST_TRANSAXIAL :
-      case MDC_SUPINE_FEETFIRST_TRANSAXIAL :
-      case MDC_PRONE_HEADFIRST_TRANSAXIAL  :
-      case MDC_PRONE_FEETFIRST_TRANSAXIAL  : break;
+      case MDC_SUPINE_HEADFIRST_SAGITTAL            :
+      case MDC_SUPINE_FEETFIRST_SAGITTAL            :
+      case MDC_PRONE_HEADFIRST_SAGITTAL             :
+      case MDC_PRONE_FEETFIRST_SAGITTAL             :
+      case MDC_SUPINE_HEADFIRST_CORONAL             :
+      case MDC_SUPINE_FEETFIRST_CORONAL             :
+      case MDC_PRONE_HEADFIRST_CORONAL              :
+      case MDC_PRONE_FEETFIRST_CORONAL              :
+      case MDC_SUPINE_HEADFIRST_TRANSAXIAL          :
+      case MDC_SUPINE_FEETFIRST_TRANSAXIAL          :
+      case MDC_PRONE_HEADFIRST_TRANSAXIAL           :
+      case MDC_PRONE_FEETFIRST_TRANSAXIAL           : 
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    :
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     :
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL  :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL  : break;
       default:
         MdcPrntWarn("stack slices : Probably file with Non-Orthogonal slices");
     }
@@ -419,18 +431,30 @@ char *MdcStackFrames(void)
   if (ofi->planar == MDC_NO) {
     /* check for orthogonal slices */
     switch (ofi->pat_slice_orient) {
-      case MDC_SUPINE_HEADFIRST_SAGITTAL   :
-      case MDC_SUPINE_FEETFIRST_SAGITTAL   :
-      case MDC_PRONE_HEADFIRST_SAGITTAL    :
-      case MDC_PRONE_FEETFIRST_SAGITTAL    :
-      case MDC_SUPINE_HEADFIRST_CORONAL    :
-      case MDC_SUPINE_FEETFIRST_CORONAL    :
-      case MDC_PRONE_HEADFIRST_CORONAL     :
-      case MDC_PRONE_FEETFIRST_CORONAL     :
-      case MDC_SUPINE_HEADFIRST_TRANSAXIAL :
-      case MDC_SUPINE_FEETFIRST_TRANSAXIAL :
-      case MDC_PRONE_HEADFIRST_TRANSAXIAL  :
-      case MDC_PRONE_FEETFIRST_TRANSAXIAL  : break;
+      case MDC_SUPINE_HEADFIRST_SAGITTAL            :
+      case MDC_SUPINE_FEETFIRST_SAGITTAL            :
+      case MDC_PRONE_HEADFIRST_SAGITTAL             :
+      case MDC_PRONE_FEETFIRST_SAGITTAL             :
+      case MDC_SUPINE_HEADFIRST_CORONAL             :
+      case MDC_SUPINE_FEETFIRST_CORONAL             :
+      case MDC_PRONE_HEADFIRST_CORONAL              :
+      case MDC_PRONE_FEETFIRST_CORONAL              :
+      case MDC_SUPINE_HEADFIRST_TRANSAXIAL          :
+      case MDC_SUPINE_FEETFIRST_TRANSAXIAL          :
+      case MDC_PRONE_HEADFIRST_TRANSAXIAL           :
+      case MDC_PRONE_FEETFIRST_TRANSAXIAL           : 
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_SAGITTAL   :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_SAGITTAL   :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_SAGITTAL    :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_SAGITTAL    :
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_CORONAL    :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_CORONAL    :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_CORONAL     :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_CORONAL     :
+      case MDC_DECUBITUS_RIGHT_HEADFIRST_TRANSAXIAL :
+      case MDC_DECUBITUS_RIGHT_FEETFIRST_TRANSAXIAL :
+      case MDC_DECUBITUS_LEFT_HEADFIRST_TRANSAXIAL  :
+      case MDC_DECUBITUS_LEFT_FEETFIRST_TRANSAXIAL  : break;
       default:
         MdcPrntWarn("stack frames : Probably file with Non-Orthogonal slices");
     }
