@@ -37,7 +37,7 @@
  *                MdcCleanUpFI()        - Clean up FILEINFO struct         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.c,v 1.64 2005/05/16 07:35:02 enlf Exp $ 
+/* $Id: m-structs.c,v 1.69 2005/12/16 23:31:55 enlf Exp $ 
  */
 
 /*
@@ -323,11 +323,9 @@ void MdcInitID(IMG_DATA *id)
   id->pixel_ysize = 1.;
   id->slice_width = 1.;
 
-  for(i=0;i<3;i++) { id->image_pos_dev[i]=0.;    id->image_pos_pat[i]=0.;}
-  for(i=0;i<6;i++) { id->image_orient_dev[i]=0.; id->image_orient_pat[i]=0.;}
-
+  for(i=0;i<3;i++) { id->image_pos_dev[i]=0.;    id->image_pos_pat[i]=0.; }
+  for(i=0;i<6;i++) { id->image_orient_dev[i]=0.; id->image_orient_pat[i]=0.; }
   id->slice_spacing = 0.; /* = slice_width; when not found no gap */ 
-
   id->ct_zoom_fctr  = 1.;
  
   id->sdata = NULL;
@@ -439,6 +437,10 @@ void MdcInitFI(FILEINFO *fi, char *path)
    fi->planar            = MDC_NO;
    fi->reconstructed     = MDC_YES;
 
+   fi->contrast_remapped = MDC_NO;
+   fi->window_centre = 0.;
+   fi->window_width  = 0.;
+
    fi->slice_projection = MDC_UNKNOWN;
    fi->pat_slice_orient = MDC_UNKNOWN;
 
@@ -633,8 +635,8 @@ char *MdcCopyID(IMG_DATA *dest, IMG_DATA *src, int COPY_IMAGE)
     dest->intercept = 0.;
   }
 
-  dest->frame_number   = src->frame_number;
-  dest->slice_start    = src->slice_start;
+  dest->frame_number = src->frame_number;
+  dest->slice_start  = src->slice_start;
 
   dest->quant_units  = src->quant_units;
   dest->calibr_units = src->calibr_units;
@@ -642,7 +644,7 @@ char *MdcCopyID(IMG_DATA *dest, IMG_DATA *src, int COPY_IMAGE)
   dest->pixel_xsize  = src->pixel_xsize;
   dest->pixel_ysize  = src->pixel_ysize;
   dest->slice_width  = src->slice_width;
-  dest->recon_scale      = src->recon_scale;
+  dest->recon_scale  = src->recon_scale;
 
   for (i=0; i<3; i++) dest->image_pos_dev[i] = src->image_pos_dev[i];
   for (i=0; i<6; i++) dest->image_orient_dev[i] = src->image_orient_dev[i];
@@ -657,12 +659,17 @@ char *MdcCopyID(IMG_DATA *dest, IMG_DATA *src, int COPY_IMAGE)
     dest->sdata = (STATIC_DATA *)malloc(sizeof(STATIC_DATA));
     if (dest->sdata == NULL) return("Failed to copy static data struct");
     MdcCopySD(dest->sdata,src->sdata);
+  }else{
+    dest->sdata = NULL;
   }
 
+  /* no copying here; just initialize plugb */
+  dest->plugb = NULL;
+
   return(NULL);
 }
 
-/* KEEP_FILES : preserve file pointers - safe when copy will be replacement */
+/* KEEP_FILES = preserve file pointers; src pointers are masked (!) */
 char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
 {
   char *msg=NULL;
@@ -671,10 +678,14 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
   MdcInitFI(dest,src->ifname);
 
   if (KEEP_FILES == MDC_YES) {
+    /* copy pointers */
     dest->ifp = src->ifp;
     dest->ifp_raw = src->ifp_raw;
     dest->ofp = src->ofp;
     dest->ofp_raw = src->ofp_raw;
+    /* mask src pointers */
+    src->ifp = NULL; src->ifp_raw = NULL;
+    src->ofp = NULL; src->ofp_raw = NULL;
   }
 
   memcpy(dest->ipath,src->ipath,MDC_MAX_PATH);
@@ -706,6 +717,10 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
   dest->qglmin      = src->qglmin;
   dest->qglmax      = src->qglmax;
 
+  dest->contrast_remapped = src->contrast_remapped;
+  dest->window_centre = src->window_centre;
+  dest->window_width  = src->window_width;
+
   dest->slice_projection = src->slice_projection;
   dest->pat_slice_orient = src->pat_slice_orient;
 
@@ -763,6 +778,8 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
       dest->comm_length = src->comm_length;
       memcpy(dest->comment,src->comment,dest->comm_length);
     }
+  }else{
+   dest->comm_length = 0; dest->comment = NULL; 
   }
 
   /* copy ACQ_DATA structs */
@@ -835,6 +852,8 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
     dest->mod = (MOD_INFO *)malloc(sizeof(MOD_INFO));
     if (dest->mod == NULL) return("Failed to copy MOD_INFO struct");
     MdcCopyMOD(dest->mod,src->mod);
+  }else{
+    dest->mod = NULL;
   }
 
   return(NULL);
