@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.h,v 1.47 2005/05/16 07:35:02 enlf Exp $
+/* $Id: m-structs.h,v 1.48 2005/12/16 23:31:55 enlf Exp $
  */
 
 /*
@@ -252,6 +252,10 @@ typedef struct File_Info_t {
   double glmin, glmax;           /* global min/max value   */
   double qglmin, qglmax;         /* quantified min/max     */
 
+  Int8  contrast_remapped;       /* contrast remap applied */
+  float window_centre;           /* contrast window centre */
+  float window_width;            /* contrast window width  */
+
   Int8 slice_projection;         /* projection of images   */
   Int8 pat_slice_orient;         /* combined flag          */
   char pat_pos[MDC_MAXSTR];      /* patient position       */
