@@ -11,7 +11,7 @@
  *                XMdcShowFileInfo()        - Display general file info    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xinfo.c,v 1.53 2005/05/16 07:35:02 enlf Exp $
+/* $Id: xinfo.c,v 1.55 2005/12/18 09:50:14 enlf Exp $
  */
 
 /*
@@ -450,6 +450,14 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   sprintf(xmdcstr,"qglmax      : %+e\n",my.fi->qglmax);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
 
+  v = (int)my.fi->contrast_remapped;
+  sprintf(xmdcstr,"contrast remapped: %d (= %s)\n",v,MdcGetStrYesNo(v));
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+  sprintf(xmdcstr,"window centre    : %g\n",my.fi->window_centre);
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+  sprintf(xmdcstr,"window width     : %g\n",my.fi->window_width);
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+
   sprintf(xmdcstr,"\nOrientation Information\n");
   gtk_text_insert(GTK_TEXT(text),NULL,&Blue,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"slice projection          : %d (= %s)\n",
