@@ -29,7 +29,7 @@
  *                XMdcInitCineButtons()            - Init cine buttons     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xoptions.c,v 1.63 2005/05/16 07:35:02 enlf Exp $
+/* $Id: xoptions.c,v 1.64 2005/12/16 23:41:18 enlf Exp $
  */
 
 /*
@@ -237,9 +237,9 @@ void XMdcOptionsMedconCallbackApply(GtkWidget *widget, gpointer data)
 
   /* DICOM */
   if (GTK_TOGGLE_BUTTON(sOptionsMedCon.DicmContrast)->active) {
-    MDC_DICOM_CONTRAST=MDC_YES;
+    MDC_CONTRAST_REMAP=MDC_YES;
   }else{
-    MDC_DICOM_CONTRAST=MDC_NO;
+    MDC_CONTRAST_REMAP=MDC_NO;
   }
 
   if (GTK_TOGGLE_BUTTON(sOptionsMedCon.DicmTrueGap)->active) {
@@ -937,7 +937,7 @@ void XMdcOptionsMedconAddTabFormats(GtkWidget *notebook)
 
   button = gtk_check_button_new_with_label("[r]  enable contrast remapping");
   gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
-  if (MDC_DICOM_CONTRAST == MDC_YES)
+  if (MDC_CONTRAST_REMAP == MDC_YES)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
   gtk_widget_show(button);
   sOptionsMedCon.DicmContrast = button;
@@ -1457,7 +1457,7 @@ void XMdcOptionsMedconSel(GtkWidget *widget, gpointer data)
 
      /* DICOM */
      b1 = sOptionsMedCon.DicmContrast;
-     if (MDC_DICOM_CONTRAST == MDC_YES)
+     if (MDC_CONTRAST_REMAP == MDC_YES)
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), TRUE);
      else
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), FALSE);
